/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qconcatenatetablesproxymodel.sip"
#include <qconcatenatetablesproxymodel.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 111 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 57 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 60 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 63 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 66 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 111 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 69 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 275 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 72 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 75 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 78 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 81 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 84 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 76 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 87 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 442 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 90 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 93 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 98 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 101 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 104 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 107 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 110 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 113 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 116 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 119 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 122 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 125 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 128 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 131 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 134 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"


class sipQConcatenateTablesProxyModel : public ::QConcatenateTablesProxyModel
{
public:
    sipQConcatenateTablesProxyModel(::QObject*);
    virtual ~sipQConcatenateTablesProxyModel();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QModelIndex index(int, int, const ::QModelIndex&) const SIP_OVERRIDE;
    ::QModelIndex parent(const ::QModelIndex&) const SIP_OVERRIDE;
    ::QModelIndex sibling(int, int, const ::QModelIndex&) const SIP_OVERRIDE;
    int rowCount(const ::QModelIndex&) const SIP_OVERRIDE;
    int columnCount(const ::QModelIndex&) const SIP_OVERRIDE;
    bool hasChildren(const ::QModelIndex&) const SIP_OVERRIDE;
    ::QVariant data(const ::QModelIndex&, int) const SIP_OVERRIDE;
    bool setData(const ::QModelIndex&, const ::QVariant&, int) SIP_OVERRIDE;
    ::QVariant headerData(int, ::Qt::Orientation, int) const SIP_OVERRIDE;
    bool setHeaderData(int, ::Qt::Orientation, const ::QVariant&, int) SIP_OVERRIDE;
    QMap<int, ::QVariant> itemData(const ::QModelIndex&) const SIP_OVERRIDE;
    bool setItemData(const ::QModelIndex&, const QMap<int, ::QVariant>&) SIP_OVERRIDE;
    ::QStringList mimeTypes() const SIP_OVERRIDE;
    ::QMimeData* mimeData(const ::QModelIndexList&) const SIP_OVERRIDE;
    bool dropMimeData(const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&) SIP_OVERRIDE;
    ::Qt::DropActions supportedDropActions() const SIP_OVERRIDE;
    bool insertRows(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    bool insertColumns(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    bool removeRows(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    bool removeColumns(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    void fetchMore(const ::QModelIndex&) SIP_OVERRIDE;
    bool canFetchMore(const ::QModelIndex&) const SIP_OVERRIDE;
    ::Qt::ItemFlags flags(const ::QModelIndex&) const SIP_OVERRIDE;
    void sort(int, ::Qt::SortOrder) SIP_OVERRIDE;
    ::QModelIndex buddy(const ::QModelIndex&) const SIP_OVERRIDE;
    ::QModelIndexList match(const ::QModelIndex&, int, const ::QVariant&, int, ::Qt::MatchFlags) const SIP_OVERRIDE;
    ::QSize span(const ::QModelIndex&) const SIP_OVERRIDE;
    bool submit() SIP_OVERRIDE;
    void revert() SIP_OVERRIDE;
    ::Qt::DropActions supportedDragActions() const SIP_OVERRIDE;
    QHash<int, ::QByteArray> roleNames() const SIP_OVERRIDE;
    bool canDropMimeData(const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&) const SIP_OVERRIDE;
    bool moveRows(const ::QModelIndex&, int, int, const ::QModelIndex&, int) SIP_OVERRIDE;
    bool moveColumns(const ::QModelIndex&, int, int, const ::QModelIndex&, int) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQConcatenateTablesProxyModel(const sipQConcatenateTablesProxyModel &);
    sipQConcatenateTablesProxyModel &operator = (const sipQConcatenateTablesProxyModel &);

    char sipPyMethods[41];
};

sipQConcatenateTablesProxyModel::sipQConcatenateTablesProxyModel(::QObject*a0): ::QConcatenateTablesProxyModel(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQConcatenateTablesProxyModel::~sipQConcatenateTablesProxyModel()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQConcatenateTablesProxyModel::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtCore_qt_metaobject(sipPySelf, sipType_QConcatenateTablesProxyModel);

    return ::QConcatenateTablesProxyModel::metaObject();
}

int sipQConcatenateTablesProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QConcatenateTablesProxyModel::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtCore_qt_metacall(sipPySelf, sipType_QConcatenateTablesProxyModel, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQConcatenateTablesProxyModel::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtCore_qt_metacast(sipPySelf, sipType_QConcatenateTablesProxyModel, _clname, &sipCpp) ? sipCpp : ::QConcatenateTablesProxyModel::qt_metacast(_clname));
}

void sipQConcatenateTablesProxyModel::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QConcatenateTablesProxyModel::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQConcatenateTablesProxyModel::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QConcatenateTablesProxyModel::connectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQConcatenateTablesProxyModel::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QConcatenateTablesProxyModel::customEvent(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQConcatenateTablesProxyModel::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QConcatenateTablesProxyModel::childEvent(a0);
        return;
    }

    extern void sipVH_QtCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtCore_3(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQConcatenateTablesProxyModel::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QConcatenateTablesProxyModel::timerEvent(a0);
        return;
    }

    extern void sipVH_QtCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtCore_2(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQConcatenateTablesProxyModel::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::eventFilter(a0, a1);

    extern bool sipVH_QtCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtCore_1(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

bool sipQConcatenateTablesProxyModel::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::event(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

::QModelIndex sipQConcatenateTablesProxyModel::index(int a0, int a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_index);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::index(a0, a1, a2);

    extern ::QModelIndex sipVH_QtCore_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_19(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

::QModelIndex sipQConcatenateTablesProxyModel::parent(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_parent);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::parent(a0);

    extern ::QModelIndex sipVH_QtCore_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_20(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

::QModelIndex sipQConcatenateTablesProxyModel::sibling(int a0, int a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sibling);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::sibling(a0, a1, a2);

    extern ::QModelIndex sipVH_QtCore_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_19(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

int sipQConcatenateTablesProxyModel::rowCount(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_rowCount);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::rowCount(a0);

    extern int sipVH_QtCore_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_21(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

int sipQConcatenateTablesProxyModel::columnCount(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_columnCount);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::columnCount(a0);

    extern int sipVH_QtCore_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_21(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQConcatenateTablesProxyModel::hasChildren(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasChildren);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::hasChildren(a0);

    extern bool sipVH_QtCore_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_22(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

::QVariant sipQConcatenateTablesProxyModel::data(const ::QModelIndex& a0, int a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_data);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::data(a0, a1);

    extern ::QVariant sipVH_QtCore_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int);

    return sipVH_QtCore_23(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

bool sipQConcatenateTablesProxyModel::setData(const ::QModelIndex& a0, const ::QVariant& a1, int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_setData);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::setData(a0, a1, a2);

    extern bool sipVH_QtCore_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QVariant&, int);

    return sipVH_QtCore_24(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

::QVariant sipQConcatenateTablesProxyModel::headerData(int a0, ::Qt::Orientation a1, int a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[15]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_headerData);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::headerData(a0, a1, a2);

    extern ::QVariant sipVH_QtCore_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::Orientation, int);

    return sipVH_QtCore_25(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQConcatenateTablesProxyModel::setHeaderData(int a0, ::Qt::Orientation a1, const ::QVariant& a2, int a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_setHeaderData);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::setHeaderData(a0, a1, a2, a3);

    extern bool sipVH_QtCore_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::Orientation, const ::QVariant&, int);

    return sipVH_QtCore_26(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3);
}

QMap<int, ::QVariant> sipQConcatenateTablesProxyModel::itemData(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[17]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_itemData);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::itemData(a0);

    extern QMap<int, ::QVariant> sipVH_QtCore_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_27(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQConcatenateTablesProxyModel::setItemData(const ::QModelIndex& a0, const QMap<int, ::QVariant>& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_setItemData);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::setItemData(a0, a1);

    extern bool sipVH_QtCore_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const QMap<int, ::QVariant>&);

    return sipVH_QtCore_28(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

::QStringList sipQConcatenateTablesProxyModel::mimeTypes() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[19]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mimeTypes);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::mimeTypes();

    extern ::QStringList sipVH_QtCore_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_29(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

::QMimeData* sipQConcatenateTablesProxyModel::mimeData(const ::QModelIndexList& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[20]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mimeData);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::mimeData(a0);

    extern ::QMimeData* sipVH_QtCore_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndexList&);

    return sipVH_QtCore_30(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQConcatenateTablesProxyModel::dropMimeData(const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_dropMimeData);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::dropMimeData(a0, a1, a2, a3, a4);

    extern bool sipVH_QtCore_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&);

    return sipVH_QtCore_31(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

::Qt::DropActions sipQConcatenateTablesProxyModel::supportedDropActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[22]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportedDropActions);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::supportedDropActions();

    extern ::Qt::DropActions sipVH_QtCore_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_32(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

bool sipQConcatenateTablesProxyModel::insertRows(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_insertRows);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::insertRows(a0, a1, a2);

    extern bool sipVH_QtCore_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_33(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQConcatenateTablesProxyModel::insertColumns(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_insertColumns);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::insertColumns(a0, a1, a2);

    extern bool sipVH_QtCore_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_33(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQConcatenateTablesProxyModel::removeRows(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_removeRows);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::removeRows(a0, a1, a2);

    extern bool sipVH_QtCore_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_33(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQConcatenateTablesProxyModel::removeColumns(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_removeColumns);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::removeColumns(a0, a1, a2);

    extern bool sipVH_QtCore_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_33(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQConcatenateTablesProxyModel::fetchMore(const ::QModelIndex& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_fetchMore);

    if (!sipMeth)
    {
        ::QConcatenateTablesProxyModel::fetchMore(a0);
        return;
    }

    extern void sipVH_QtCore_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    sipVH_QtCore_34(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQConcatenateTablesProxyModel::canFetchMore(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[28]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_canFetchMore);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::canFetchMore(a0);

    extern bool sipVH_QtCore_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_22(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

::Qt::ItemFlags sipQConcatenateTablesProxyModel::flags(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[29]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_flags);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::flags(a0);

    extern ::Qt::ItemFlags sipVH_QtCore_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_35(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQConcatenateTablesProxyModel::sort(int a0, ::Qt::SortOrder a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_sort);

    if (!sipMeth)
    {
        ::QConcatenateTablesProxyModel::sort(a0, a1);
        return;
    }

    extern void sipVH_QtCore_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::SortOrder);

    sipVH_QtCore_36(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

::QModelIndex sipQConcatenateTablesProxyModel::buddy(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[31]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_buddy);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::buddy(a0);

    extern ::QModelIndex sipVH_QtCore_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_20(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

::QModelIndexList sipQConcatenateTablesProxyModel::match(const ::QModelIndex& a0, int a1, const ::QVariant& a2, int a3, ::Qt::MatchFlags a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[32]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_match);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::match(a0, a1, a2, a3, a4);

    extern ::QModelIndexList sipVH_QtCore_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, const ::QVariant&, int, ::Qt::MatchFlags);

    return sipVH_QtCore_37(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

::QSize sipQConcatenateTablesProxyModel::span(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[33]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_span);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::span(a0);

    extern ::QSize sipVH_QtCore_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_38(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQConcatenateTablesProxyModel::submit()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_submit);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::submit();

    extern bool sipVH_QtCore_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_11(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

void sipQConcatenateTablesProxyModel::revert()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_revert);

    if (!sipMeth)
    {
        ::QConcatenateTablesProxyModel::revert();
        return;
    }

    extern void sipVH_QtCore_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtCore_17(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

::Qt::DropActions sipQConcatenateTablesProxyModel::supportedDragActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[36]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportedDragActions);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::supportedDragActions();

    extern ::Qt::DropActions sipVH_QtCore_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_32(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

QHash<int, ::QByteArray> sipQConcatenateTablesProxyModel::roleNames() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[37]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_roleNames);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::roleNames();

    extern QHash<int, ::QByteArray> sipVH_QtCore_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_39(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

bool sipQConcatenateTablesProxyModel::canDropMimeData(const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[38]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_canDropMimeData);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::canDropMimeData(a0, a1, a2, a3, a4);

    extern bool sipVH_QtCore_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&);

    return sipVH_QtCore_31(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQConcatenateTablesProxyModel::moveRows(const ::QModelIndex& a0, int a1, int a2, const ::QModelIndex& a3, int a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_moveRows);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::moveRows(a0, a1, a2, a3, a4);

    extern bool sipVH_QtCore_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int, const ::QModelIndex&, int);

    return sipVH_QtCore_40(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQConcatenateTablesProxyModel::moveColumns(const ::QModelIndex& a0, int a1, int a2, const ::QModelIndex& a3, int a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_moveColumns);

    if (!sipMeth)
        return ::QConcatenateTablesProxyModel::moveColumns(a0, a1, a2, a3, a4);

    extern bool sipVH_QtCore_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int, const ::QModelIndex&, int);

    return sipVH_QtCore_40(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_addSourceModel, "addSourceModel(self, sourceModel: Optional[QAbstractItemModel])");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_addSourceModel(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_addSourceModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Wrapper;
        ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, &a0Wrapper, sipType_QAbstractItemModel, &a0))
        {
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qconcatenatetablesproxymodel.sip"
        // We want to keep a reference to the model but this is in addition to the
        // existing ones and does not replace them - so we can't use /KeepReference/.
        sipCpp->addSourceModel(a0);
        
        // Use the user object as a list of the references.
        PyObject *user = sipGetUserObject((sipSimpleWrapper *)sipSelf);
        
        if (!user)
        {
            user = PyList_New(0);
            sipSetUserObject((sipSimpleWrapper *)sipSelf, user);
        }
        
        if (user)
            PyList_Append(user, a0Wrapper);
#line 913 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_addSourceModel, doc_QConcatenateTablesProxyModel_addSourceModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_removeSourceModel, "removeSourceModel(self, sourceModel: Optional[QAbstractItemModel])");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_removeSourceModel(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_removeSourceModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Wrapper;
        ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, &a0Wrapper, sipType_QAbstractItemModel, &a0))
        {
#line 55 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qconcatenatetablesproxymodel.sip"
        // Discard the extra model reference that we took in addSourceModel().
        sipCpp->removeSourceModel(a0);
        
        // Use the user object as a list of the references.
        PyObject *user = sipGetUserObject((sipSimpleWrapper *)sipSelf);
        
        if (user)
        {
            Py_ssize_t i = 0;
        
            // Note that we deal with an object appearing in the list more than once.
            while (i < PyList_Size(user))
                if (PyList_GetItem(user, i) == a0Wrapper)
                    PyList_SetSlice(user, i, i + 1, NULL);
                else
                    ++i;
        }
#line 958 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQConcatenateTablesProxyModel.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_removeSourceModel, doc_QConcatenateTablesProxyModel_removeSourceModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_mapFromSource, "mapFromSource(self, sourceIndex: QModelIndex) -> QModelIndex");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_mapFromSource(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_mapFromSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex* a0;
        const ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex(sipCpp->mapFromSource(*a0));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_mapFromSource, doc_QConcatenateTablesProxyModel_mapFromSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_mapToSource, "mapToSource(self, proxyIndex: QModelIndex) -> QModelIndex");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_mapToSource(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_mapToSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex* a0;
        const ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex(sipCpp->mapToSource(*a0));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_mapToSource, doc_QConcatenateTablesProxyModel_mapToSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_data, "data(self, index: QModelIndex, role: int = Qt.ItemDataRole.DisplayRole) -> Any");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_data(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_data(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        int a1 = Qt::ItemDataRole::DisplayRole;
        const ::QConcatenateTablesProxyModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|i", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0, &a1))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::data(*a0, a1) : sipCpp->data(*a0, a1)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_data, doc_QConcatenateTablesProxyModel_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_setData, "setData(self, index: QModelIndex, value: Any, role: int = Qt.ItemDataRole.EditRole) -> bool");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_setData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_setData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QVariant* a1;
        int a1State = 0;
        int a2 = Qt::ItemDataRole::EditRole;
        ::QConcatenateTablesProxyModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9J1|i", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0, sipType_QVariant, &a1, &a1State, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::setData(*a0, *a1, a2) : sipCpp->setData(*a0, *a1, a2));
            sipReleaseType(const_cast<::QVariant *>(a1), sipType_QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_setData, doc_QConcatenateTablesProxyModel_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_itemData, "itemData(self, proxyIndex: QModelIndex) -> Dict[int, Any]");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_itemData(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_itemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            QMap<int, ::QVariant>*sipRes;

            sipRes = new QMap<int, ::QVariant>((sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::itemData(*a0) : sipCpp->itemData(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QMap_1800_0100QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_itemData, doc_QConcatenateTablesProxyModel_itemData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_setItemData, "setItemData(self, index: QModelIndex, roles: Dict[int, Any]) -> bool");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_setItemData(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_setItemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const QMap<int, ::QVariant>* a1;
        int a1State = 0;
        ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0, sipType_QMap_1800_0100QVariant, &a1, &a1State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::setItemData(*a0, *a1) : sipCpp->setItemData(*a0, *a1));
            sipReleaseType(const_cast<QMap<int, ::QVariant> *>(a1), sipType_QMap_1800_0100QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_setItemData, doc_QConcatenateTablesProxyModel_setItemData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_flags, "flags(self, index: QModelIndex) -> Qt.ItemFlags");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_flags(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::Qt::ItemFlags*sipRes;

            sipRes = new ::Qt::ItemFlags((sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::flags(*a0) : sipCpp->flags(*a0)));

            return sipConvertFromNewType(sipRes, sipType_Qt_ItemFlags, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_flags, doc_QConcatenateTablesProxyModel_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_index, "index(self, row: int, column: int, parent: QModelIndex = QModelIndex()) -> QModelIndex");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_index(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_index(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = QModelIndex();
        const ::QModelIndex* a2 = &a2def;
        const ::QConcatenateTablesProxyModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex((sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::index(a0, a1, *a2) : sipCpp->index(a0, a1, *a2)));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_index, doc_QConcatenateTablesProxyModel_index);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_parent, "parent(self, index: QModelIndex) -> QModelIndex");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_parent(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_parent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex((sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::parent(*a0) : sipCpp->parent(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_parent, doc_QConcatenateTablesProxyModel_parent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_rowCount, "rowCount(self, parent: QModelIndex = QModelIndex()) -> int");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_rowCount(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_rowCount(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex& a0def = QModelIndex();
        const ::QModelIndex* a0 = &a0def;
        const ::QConcatenateTablesProxyModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::rowCount(*a0) : sipCpp->rowCount(*a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_rowCount, doc_QConcatenateTablesProxyModel_rowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_headerData, "headerData(self, section: int, orientation: Qt.Orientation, role: int = Qt.ItemDataRole.DisplayRole) -> Any");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_headerData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_headerData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::Qt::Orientation a1;
        int a2 = Qt::ItemDataRole::DisplayRole;
        const ::QConcatenateTablesProxyModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiE|i", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, &a0, sipType_Qt_Orientation, &a1, &a2))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::headerData(a0, a1, a2) : sipCpp->headerData(a0, a1, a2)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_headerData, doc_QConcatenateTablesProxyModel_headerData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_columnCount, "columnCount(self, parent: QModelIndex = QModelIndex()) -> int");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_columnCount(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_columnCount(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex& a0def = QModelIndex();
        const ::QModelIndex* a0 = &a0def;
        const ::QConcatenateTablesProxyModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::columnCount(*a0) : sipCpp->columnCount(*a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_columnCount, doc_QConcatenateTablesProxyModel_columnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_mimeTypes, "mimeTypes(self) -> List[str]");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_mimeTypes(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_mimeTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList((sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::mimeTypes() : sipCpp->mimeTypes()));

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_mimeTypes, doc_QConcatenateTablesProxyModel_mimeTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_mimeData, "mimeData(self, indexes: Iterable[QModelIndex]) -> Optional[QMimeData]");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_mimeData(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_mimeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndexList* a0;
        int a0State = 0;
        const ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QList_0100QModelIndex, &a0, &a0State))
        {
            ::QMimeData*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::mimeData(*a0) : sipCpp->mimeData(*a0));
            sipReleaseType(const_cast<::QModelIndexList *>(a0), sipType_QList_0100QModelIndex, a0State);

            return sipConvertFromType(sipRes, sipType_QMimeData, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_mimeData, doc_QConcatenateTablesProxyModel_mimeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_canDropMimeData, "canDropMimeData(self, data: Optional[QMimeData], action: Qt.DropAction, row: int, column: int, parent: QModelIndex) -> bool");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_canDropMimeData(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_canDropMimeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QMimeData* a0;
        ::Qt::DropAction a1;
        int a2;
        int a3;
        const ::QModelIndex* a4;
        const ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8EiiJ9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QMimeData, &a0, sipType_Qt_DropAction, &a1, &a2, &a3, sipType_QModelIndex, &a4))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::canDropMimeData(a0, a1, a2, a3, *a4) : sipCpp->canDropMimeData(a0, a1, a2, a3, *a4));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_canDropMimeData, doc_QConcatenateTablesProxyModel_canDropMimeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_dropMimeData, "dropMimeData(self, data: Optional[QMimeData], action: Qt.DropAction, row: int, column: int, parent: QModelIndex) -> bool");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_dropMimeData(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_dropMimeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QMimeData* a0;
        ::Qt::DropAction a1;
        int a2;
        int a3;
        const ::QModelIndex* a4;
        ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8EiiJ9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QMimeData, &a0, sipType_Qt_DropAction, &a1, &a2, &a3, sipType_QModelIndex, &a4))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::dropMimeData(a0, a1, a2, a3, *a4) : sipCpp->dropMimeData(a0, a1, a2, a3, *a4));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_dropMimeData, doc_QConcatenateTablesProxyModel_dropMimeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_span, "span(self, index: QModelIndex) -> QSize");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_span(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_span(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QConcatenateTablesProxyModel::span(*a0) : sipCpp->span(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_span, doc_QConcatenateTablesProxyModel_span);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QConcatenateTablesProxyModel_sourceModels, "sourceModels(self) -> List[QAbstractItemModel]");

extern "C" {static PyObject *meth_QConcatenateTablesProxyModel_sourceModels(PyObject *, PyObject *);}
static PyObject *meth_QConcatenateTablesProxyModel_sourceModels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QConcatenateTablesProxyModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QConcatenateTablesProxyModel, &sipCpp))
        {
            QList<::QAbstractItemModel*>*sipRes;

            sipRes = new QList<::QAbstractItemModel*>(sipCpp->sourceModels());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QAbstractItemModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QConcatenateTablesProxyModel, sipName_sourceModels, doc_QConcatenateTablesProxyModel_sourceModels);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QConcatenateTablesProxyModel(void *, const sipTypeDef *);}
static void *cast_QConcatenateTablesProxyModel(void *sipCppV, const sipTypeDef *targetType)
{
    ::QConcatenateTablesProxyModel *sipCpp = reinterpret_cast<::QConcatenateTablesProxyModel *>(sipCppV);

    if (targetType == sipType_QConcatenateTablesProxyModel)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstractItemModel)->ctd_cast(static_cast<::QAbstractItemModel *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QConcatenateTablesProxyModel(void *, int);}
static void release_QConcatenateTablesProxyModel(void *sipCppV, int)
{
    ::QConcatenateTablesProxyModel *sipCpp = reinterpret_cast<::QConcatenateTablesProxyModel *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QConcatenateTablesProxyModel(Py_ssize_t);}
static void *array_QConcatenateTablesProxyModel(Py_ssize_t sipNrElem)
{
    return new ::QConcatenateTablesProxyModel[sipNrElem];
}


extern "C" {static void array_delete_QConcatenateTablesProxyModel(void *);}
static void array_delete_QConcatenateTablesProxyModel(void *sipCpp)
{
    delete[] reinterpret_cast<::QConcatenateTablesProxyModel *>(sipCpp);
}


extern "C" {static void dealloc_QConcatenateTablesProxyModel(sipSimpleWrapper *);}
static void dealloc_QConcatenateTablesProxyModel(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQConcatenateTablesProxyModel *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QConcatenateTablesProxyModel(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QConcatenateTablesProxyModel(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QConcatenateTablesProxyModel(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQConcatenateTablesProxyModel *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQConcatenateTablesProxyModel(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QConcatenateTablesProxyModel[] = {{6, 255, 1}};


static PyMethodDef methods_QConcatenateTablesProxyModel[] = {
    {sipName_addSourceModel, meth_QConcatenateTablesProxyModel_addSourceModel, METH_VARARGS, doc_QConcatenateTablesProxyModel_addSourceModel},
    {sipName_canDropMimeData, meth_QConcatenateTablesProxyModel_canDropMimeData, METH_VARARGS, doc_QConcatenateTablesProxyModel_canDropMimeData},
    {sipName_columnCount, SIP_MLMETH_CAST(meth_QConcatenateTablesProxyModel_columnCount), METH_VARARGS|METH_KEYWORDS, doc_QConcatenateTablesProxyModel_columnCount},
    {sipName_data, SIP_MLMETH_CAST(meth_QConcatenateTablesProxyModel_data), METH_VARARGS|METH_KEYWORDS, doc_QConcatenateTablesProxyModel_data},
    {sipName_dropMimeData, meth_QConcatenateTablesProxyModel_dropMimeData, METH_VARARGS, doc_QConcatenateTablesProxyModel_dropMimeData},
    {sipName_flags, meth_QConcatenateTablesProxyModel_flags, METH_VARARGS, doc_QConcatenateTablesProxyModel_flags},
    {sipName_headerData, SIP_MLMETH_CAST(meth_QConcatenateTablesProxyModel_headerData), METH_VARARGS|METH_KEYWORDS, doc_QConcatenateTablesProxyModel_headerData},
    {sipName_index, SIP_MLMETH_CAST(meth_QConcatenateTablesProxyModel_index), METH_VARARGS|METH_KEYWORDS, doc_QConcatenateTablesProxyModel_index},
    {sipName_itemData, meth_QConcatenateTablesProxyModel_itemData, METH_VARARGS, doc_QConcatenateTablesProxyModel_itemData},
    {sipName_mapFromSource, meth_QConcatenateTablesProxyModel_mapFromSource, METH_VARARGS, doc_QConcatenateTablesProxyModel_mapFromSource},
    {sipName_mapToSource, meth_QConcatenateTablesProxyModel_mapToSource, METH_VARARGS, doc_QConcatenateTablesProxyModel_mapToSource},
    {sipName_mimeData, meth_QConcatenateTablesProxyModel_mimeData, METH_VARARGS, doc_QConcatenateTablesProxyModel_mimeData},
    {sipName_mimeTypes, meth_QConcatenateTablesProxyModel_mimeTypes, METH_VARARGS, doc_QConcatenateTablesProxyModel_mimeTypes},
    {sipName_parent, meth_QConcatenateTablesProxyModel_parent, METH_VARARGS, doc_QConcatenateTablesProxyModel_parent},
    {sipName_removeSourceModel, meth_QConcatenateTablesProxyModel_removeSourceModel, METH_VARARGS, doc_QConcatenateTablesProxyModel_removeSourceModel},
    {sipName_rowCount, SIP_MLMETH_CAST(meth_QConcatenateTablesProxyModel_rowCount), METH_VARARGS|METH_KEYWORDS, doc_QConcatenateTablesProxyModel_rowCount},
    {sipName_setData, SIP_MLMETH_CAST(meth_QConcatenateTablesProxyModel_setData), METH_VARARGS|METH_KEYWORDS, doc_QConcatenateTablesProxyModel_setData},
    {sipName_setItemData, meth_QConcatenateTablesProxyModel_setItemData, METH_VARARGS, doc_QConcatenateTablesProxyModel_setItemData},
    {sipName_sourceModels, meth_QConcatenateTablesProxyModel_sourceModels, METH_VARARGS, doc_QConcatenateTablesProxyModel_sourceModels},
    {sipName_span, meth_QConcatenateTablesProxyModel_span, METH_VARARGS, doc_QConcatenateTablesProxyModel_span}
};

PyDoc_STRVAR(doc_QConcatenateTablesProxyModel, "\1QConcatenateTablesProxyModel(parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QConcatenateTablesProxyModel = {
    &::QConcatenateTablesProxyModel::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QConcatenateTablesProxyModel = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QConcatenateTablesProxyModel,
        SIP_NULLPTR,
        &plugin_QConcatenateTablesProxyModel,
    },
    {
        sipNameNr_QConcatenateTablesProxyModel,
        {0, 0, 1},
        20, methods_QConcatenateTablesProxyModel,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QConcatenateTablesProxyModel,
    -1,
    -1,
    supers_QConcatenateTablesProxyModel,
    SIP_NULLPTR,
    init_type_QConcatenateTablesProxyModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QConcatenateTablesProxyModel,
    SIP_NULLPTR,
    array_QConcatenateTablesProxyModel,
    SIP_NULLPTR,
    release_QConcatenateTablesProxyModel,
    cast_QConcatenateTablesProxyModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QConcatenateTablesProxyModel,
    sizeof (::QConcatenateTablesProxyModel),
};
